@@ -1,11 +1,15 @@
 use super::*;
 
 mod detailed;
+mod item;
+mod ordered;
+mod orderless;
 mod prefix;
-mod simple;
+mod quote;
 
-pub use self::{detailed::ListDetailedNode, simple::ListSimpleNode};
-pub use self::prefix::ListPrefixSymbol;
+pub use self::{
+    detailed::DetailedList, item::ListItem, ordered::OrderedList, orderless::OrderlessList, prefix::ListPrefixSymbol, quote::QuoteList,
+};
 
 #[derive(Clone, Eq, PartialEq, Hash)]
 pub enum ListView {
@@ -18,7 +22,7 @@ pub enum ListView {
     ///
     /// > part4
     /// ```
-    Quote(Box<ListSimpleNode>),
+    Quote(Box<QuoteList>),
     /// ## Ordered List
     /// ```note
     /// 1.1. part1
@@ -28,7 +32,7 @@ pub enum ListView {
     ///
     /// 1.4. part4
     /// ```
-    Ordered(Box<ListSimpleNode>),
+    Ordered(Box<OrderedList>),
     /// ## Orderless List
     /// ```note
     /// - part1
@@ -38,26 +42,27 @@ pub enum ListView {
     ///
     /// - part4
     /// ```
-    Orderless(Box<ListSimpleNode>),
+    Orderless(Box<OrderlessList>),
 
-    Details(Box<ListDetailedNode>),
+    Details(Box<DetailedList>),
 }
 
-#[derive(Clone, Debug, Eq, PartialEq, Hash)]
-pub struct ListItem {
-    prefix: Literal<ListPrefixSymbol>,
-    rest: ASTNodes,
-}
-
-
 impl From<ListView> for ASTNode {
     fn from(node: ListView) -> Self {
         Self { value: ASTKind::ListView(node), range: None }
     }
 }
 
-impl From<ASTNodes> for ListItem {
-    fn from(node: ASTNodes) -> Self {
-        Self { prefix: Default::default(), rest: node }
-    }
+macro_rules! list_view {
+    (@ASTKind => $name:ident) => {
+        #[inline]
+        pub fn $name(children: Vec<ListItem>) -> ASTNode {
+            ListView::$name(children).into()
+        }
+    };
+    ($($name:ident),+ $(,)?) => (
+        impl ASTKind { $(list_view!(@ASTKind => $name);)+ }
+    );
 }
+
+list_view![ordered_list, orderless_list];
